@@ -326,7 +326,7 @@ class TaskCommandsTestCase(test.TestCase):
         test_uuid = "17860c43-2274-498d-8669-448eff7b073f"
         self.task.abort(self.fake_api, test_uuid)
         self.fake_api.task.abort.assert_called_once_with(
-            task_uuid=test_uuid, soft=False, async=False)
+            task_uuid=test_uuid, soft=False, wait=True)
 
     @mock.patch("rally.cli.commands.task.envutils.get_global")
     def test_abort_no_task_id(self, mock_get_global):
@@ -347,10 +347,12 @@ class TaskCommandsTestCase(test.TestCase):
         self.assertRaises(exceptions.InvalidArgumentsException,
                           self.task.status, None)
 
-    @ddt.data({"iterations_data": False, "has_output": True},
-              {"iterations_data": True, "has_output": False})
+    @ddt.data({"iterations_data": False, "has_output": True,
+               "filters": None},
+              {"iterations_data": True, "has_output": False,
+               "filters": ["scenario=fake_name", "sla_failures"]})
     @ddt.unpack
-    def test_detailed(self, iterations_data, has_output):
+    def test_detailed(self, iterations_data, has_output, filters):
         test_uuid = "c0d874d4-7195-4fd5-8688-abe82bfad36f"
         detailed_value = {
             "id": "task", "uuid": test_uuid,
@@ -485,7 +487,8 @@ class TaskCommandsTestCase(test.TestCase):
                 "additive": [], "complete": []}
         self.fake_api.task.get.return_value = detailed_value
         self.task.detailed(self.fake_api, test_uuid,
-                           iterations_data=iterations_data)
+                           iterations_data=iterations_data,
+                           filters=filters)
         self.fake_api.task.get.assert_called_once_with(
             task_id=test_uuid, detailed=True)
 
@@ -646,77 +649,14 @@ class TaskCommandsTestCase(test.TestCase):
                        consts.TaskStatus.ABORTED)))
         mock_stdout.write.assert_has_calls([mock.call(expected_out)])
 
-    @mock.patch("rally.cli.commands.task.os.path")
-    @mock.patch("rally.cli.commands.task.open", create=True)
-    @mock.patch("rally.cli.commands.task.plot")
-    @mock.patch("rally.cli.commands.task.webbrowser")
-    def test_trends(self, mock_webbrowser, mock_plot,
-                    mock_open, mock_os_path):
-        mock_os_path.exists = lambda p: p.startswith("path_to_")
-        mock_os_path.expanduser = lambda p: p + "_expanded"
-        mock_os_path.realpath.side_effect = lambda p: "realpath_" + p
-        self.task._load_task_results_file = mock.MagicMock(
-            return_value=["result_1_from_file", "result_2_from_file"]
-        )
-        mock_fd = mock.mock_open()
-        mock_open.side_effect = mock_fd
-
-        task_obj = self._make_task()
-        self.fake_api.task.get.return_value = task_obj
-        mock_plot.trends.return_value = "rendered_trends_report"
-
-        ret = self.task.trends(self.fake_api,
-                               tasks=["ab123456-38d8-4c8f-bbcc-fc8f74b004ae",
-                                      "cd654321-38d8-4c8f-bbcc-fc8f74b004ae",
-                                      "path_to_file"],
-                               out="output.html", out_format="html")
-        expected = [task_obj, task_obj,
-                    "result_1_from_file", "result_2_from_file"]
-        mock_plot.trends.assert_called_once_with(expected)
-        self.assertEqual([mock.call(self.fake_api, "path_to_file")],
-                         self.task._load_task_results_file.mock_calls)
-        self.assertEqual([mock.call("output.html_expanded", "w+")],
-                         mock_open.mock_calls)
-        self.assertIsNone(ret)
-        self.assertFalse(mock_webbrowser.open_new_tab.called)
-        mock_fd.return_value.write.assert_called_once_with(
-            "rendered_trends_report")
-
-    @mock.patch("rally.cli.commands.task.os.path")
-    @mock.patch("rally.cli.commands.task.open", create=True)
-    @mock.patch("rally.cli.commands.task.plot")
-    @mock.patch("rally.cli.commands.task.webbrowser")
-    def test_trends_single_file_and_open_webbrowser(
-            self, mock_webbrowser, mock_plot, mock_open, mock_os_path):
-        mock_os_path.exists.return_value = True
-        mock_os_path.expanduser = lambda path: path
-        mock_os_path.realpath.side_effect = lambda p: "realpath_" + p
-        self.task._load_task_results_file = mock.MagicMock(
-            return_value=["result"]
-        )
-        ret = self.task.trends(self.real_api,
-                               tasks=["path_to_file"], open_it=True,
-                               out="output.html", out_format="html")
-        self.assertIsNone(ret)
-        mock_webbrowser.open_new_tab.assert_called_once_with(
-            "file://realpath_output.html")
-
-    @mock.patch("rally.cli.commands.task.os.path")
-    @mock.patch("rally.cli.commands.task.open", create=True)
-    @mock.patch("rally.cli.commands.task.plot")
-    def test_trends_task_id_is_not_uuid_like(self, mock_plot,
-                                             mock_open, mock_os_path):
-        mock_os_path.exists.return_value = False
-
-        ret = self.task.trends(self.fake_api,
-                               tasks=["ab123456-38d8-4c8f-bbcc-fc8f74b004ae"],
-                               out="output.html", out_format="html")
-        self.assertIsNone(ret)
-
-        ret = self.task.trends(self.fake_api,
-                               tasks=["this-is-not-uuid"],
-                               out="output.html", out_format="html")
-        self.assertEqual(1, ret)
+    def test_trends(self):
+        self.task.export = mock.MagicMock()
+        self.task.trends(self.fake_api,
+                         tasks=["uuid"],
+                         out="output.html")
+        self.task.export.assert_called_once_with(
+            self.fake_api, tasks=["uuid"], output_type="trends-html",
+            output_dest="output.html", open_it=False)
 
     def test_trends_no_tasks_given(self):
         ret = self.task.trends(self.fake_api, tasks=[],
@@ -729,7 +669,7 @@ class TaskCommandsTestCase(test.TestCase):
                          out="out", open_it=False, out_format="junit-xml")
         self.task.export.assert_called_once_with(
             self.fake_api, tasks="uuid", output_type="junit-xml",
-            output_dest="out", open_it=False
+            output_dest="out", open_it=False, deployment=None
         )
 
     @mock.patch("rally.cli.commands.task.cliutils.print_list")
@@ -975,7 +915,6 @@ class TaskCommandsTestCase(test.TestCase):
         )
         mock_print.assert_called_once_with("content")
 
-    @mock.patch("rally.cli.commands.task.plot.charts")
     @mock.patch("rally.cli.commands.task.sys.stdout")
     @ddt.data({"error_type": "test_no_trace_type",
                "error_message": "no_trace_error_message",
@@ -987,9 +926,8 @@ class TaskCommandsTestCase(test.TestCase):
                })
     @ddt.unpack
     def test_show_task_errors_no_trace(self, mock_stdout,
-                                       mock_charts, error_type, error_message,
+                                       error_type, error_message,
                                        error_traceback=None):
-        mock_charts.MainStatsTable.columns = ["Column 1", "Column 2"]
         test_uuid = "test_task_id"
         error_data = [error_type, error_message]
         if error_traceback:
@@ -1114,33 +1052,32 @@ class TaskCommandsTestCase(test.TestCase):
             "statistics": {"durations": mock.ANY}
         }
 
-        results = [
-            {"hooks": [{"config": {
-                "name": "foo",
-                "args": {"arg1": "v1"},
-                "description": "descr",
-                "trigger": {"name": "t",
-                            "args": {"a2", "v2"}}}}],
-             "key": {"name": workload["name"],
-                     "description": workload["description"],
-                     "pos": workload["position"],
-                     "kw": {
-                         "args": workload["args"],
-                         "runner": {"type": "constant", "time": 3},
-                         "hooks": [{"name": "foo",
-                                    "args": {"arg1": "v1"},
-                                    "description": "descr",
-                                    "trigger": {
-                                        "name": "t",
-                                        "args": {"a2", "v2"}
-                                    }}],
-                         "sla": workload["sla"],
-                         "context": workload["contexts"]}},
-             "sla": workload["sla_results"]["sla"],
-             "result": workload["data"],
-             "full_duration": workload["full_duration"],
-             "load_duration": workload["load_duration"],
-             "created_at": "2017-01-07T07:03:01"}
+        results = [{
+            "hooks": [{
+                "config": {
+                    "name": "foo",
+                    "args": {"arg1": "v1"},
+                    "description": "descr",
+                    "trigger": {"name": "t", "args": {"a2", "v2"}}}}],
+            "key": {
+                "name": workload["name"],
+                "description": workload["description"],
+                "pos": workload["position"],
+                "kw": {
+                    "args": workload["args"],
+                    "runner": {"type": "constant", "time": 3},
+                    "hooks": [{
+                        "name": "foo",
+                        "args": {"arg1": "v1"},
+                        "description": "descr",
+                        "trigger": {"name": "t", "args": {"a2", "v2"}}}],
+                    "sla": workload["sla"],
+                    "context": workload["contexts"]}},
+            "sla": workload["sla_results"]["sla"],
+            "result": workload["data"],
+            "full_duration": workload["full_duration"],
+            "load_duration": workload["load_duration"],
+            "created_at": "2017-01-07T07:03:01"}
         ]
         mock_loads.return_value = results
         ret = self.task._load_task_results_file(self.fake_api, task_file)
@@ -1149,6 +1086,9 @@ class TaskCommandsTestCase(test.TestCase):
             "title": "Task loaded from a file.",
             "description": "Auto-ported from task format V1.",
             "uuid": "n/a",
+            "env_uuid": "n/a",
+            "env_name": "n/a",
+            "status": "finished",
             "tags": [],
             "subtasks": [{
                 "title": "A SubTask",
@@ -1163,6 +1103,8 @@ class TaskCommandsTestCase(test.TestCase):
         task_file = "/tmp/task.json"
         results = {
             "tasks": [{
+                "env_uuid": "env-uuid-1",
+                "env_name": "env-name-1",
                 "subtasks": [{
                     "workloads": [{
                         "contexts": "contexts",
@@ -1179,6 +1121,8 @@ class TaskCommandsTestCase(test.TestCase):
         mock_loads.return_value = results
         ret = self.task._load_task_results_file(self.fake_api, task_file)
         self.assertEqual([{
+            "env_uuid": "env-uuid-1",
+            "env_name": "env-name-1",
             "subtasks": [{
                 "workloads": [{
                     "args": {},
